@@ -1,15 +1,20 @@
 /*
- * Copyright (C) 1999-2002, 2004-2009, 2011, 2013, 2014, 2016  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
 /*! \file */
 
 #include <config.h>
 
+#include <stdbool.h>
+
 #include <isc/mem.h>
 #include <isc/once.h>
 #include <isc/string.h>
@@ -59,7 +64,7 @@ dns_acl_create(isc_mem_t *mctx, int n, dns_acl_t **target) {
 	acl->elements = NULL;
 	acl->alloc = 0;
 	acl->length = 0;
-	acl->has_negatives = ISC_FALSE;
+	acl->has_negatives = false;
 
 	ISC_LINK_INIT(acl, nextincache);
 	/*
@@ -89,7 +94,7 @@ dns_acl_create(isc_mem_t *mctx, int n, dns_acl_t **target) {
  * "none" is the same as "!any".
  */
 static isc_result_t
-dns_acl_anyornone(isc_mem_t *mctx, isc_boolean_t neg, dns_acl_t **target) {
+dns_acl_anyornone(isc_mem_t *mctx, bool neg, dns_acl_t **target) {
 	isc_result_t result;
 	dns_acl_t *acl = NULL;
 
@@ -97,7 +102,7 @@ dns_acl_anyornone(isc_mem_t *mctx, isc_boolean_t neg, dns_acl_t **target) {
 	if (result != ISC_R_SUCCESS)
 		return (result);
 
-	result = dns_iptable_addprefix(acl->iptable, NULL, 0, ISC_TF(!neg));
+	result = dns_iptable_addprefix(acl->iptable, NULL, 0, !neg);
 	if (result != ISC_R_SUCCESS) {
 		dns_acl_detach(&acl);
 		return (result);
@@ -112,7 +117,7 @@ dns_acl_anyornone(isc_mem_t *mctx, isc_boolean_t neg, dns_acl_t **target) {
  */
 isc_result_t
 dns_acl_any(isc_mem_t *mctx, dns_acl_t **target) {
-	return (dns_acl_anyornone(mctx, ISC_FALSE, target));
+	return (dns_acl_anyornone(mctx, false, target));
 }
 
 /*
@@ -120,15 +125,15 @@ dns_acl_any(isc_mem_t *mctx, dns_acl_t **target) {
  */
 isc_result_t
 dns_acl_none(isc_mem_t *mctx, dns_acl_t **target) {
-	return (dns_acl_anyornone(mctx, ISC_TRUE, target));
+	return (dns_acl_anyornone(mctx, true, target));
 }
 
 /*
- * If pos is ISC_TRUE, test whether acl is set to "{ any; }"
- * If pos is ISC_FALSE, test whether acl is set to "{ none; }"
+ * If pos is true, test whether acl is set to "{ any; }"
+ * If pos is false, test whether acl is set to "{ none; }"
  */
-static isc_boolean_t
-dns_acl_isanyornone(dns_acl_t *acl, isc_boolean_t pos)
+static bool
+dns_acl_isanyornone(dns_acl_t *acl, bool pos)
 {
 	/* Should never happen but let's be safe */
 	if (acl == NULL ||
@@ -136,37 +141,37 @@ dns_acl_isanyornone(dns_acl_t *acl, isc_boolean_t pos)
 	    acl->iptable->radix == NULL ||
 	    acl->iptable->radix->head == NULL ||
 	    acl->iptable->radix->head->prefix == NULL)
-		return (ISC_FALSE);
+		return (false);
 
 	if (acl->length != 0 || acl->node_count != 1)
-		return (ISC_FALSE);
+		return (false);
 
 	if (acl->iptable->radix->head->prefix->bitlen == 0 &&
 	    acl->iptable->radix->head->data[0] != NULL &&
 	    acl->iptable->radix->head->data[0] ==
 		    acl->iptable->radix->head->data[1] &&
-	    *(isc_boolean_t *) (acl->iptable->radix->head->data[0]) == pos)
-		return (ISC_TRUE);
+	    *(bool *) (acl->iptable->radix->head->data[0]) == pos)
+		return (true);
 
-	return (ISC_FALSE); /* All others */
+	return (false); /* All others */
 }
 
 /*
  * Test whether acl is set to "{ any; }"
  */
-isc_boolean_t
+bool
 dns_acl_isany(dns_acl_t *acl)
 {
-	return (dns_acl_isanyornone(acl, ISC_TRUE));
+	return (dns_acl_isanyornone(acl, true));
 }
 
 /*
  * Test whether acl is set to "{ none; }"
  */
-isc_boolean_t
+bool
 dns_acl_isnone(dns_acl_t *acl)
 {
-	return (dns_acl_isanyornone(acl, ISC_FALSE));
+	return (dns_acl_isanyornone(acl, false));
 }
 
 /*
@@ -191,14 +196,14 @@ isc_result_t
 dns_acl_match2(const isc_netaddr_t *reqaddr,
 	       const dns_name_t *reqsigner,
 	       const isc_netaddr_t *ecs,
-	       isc_uint8_t ecslen,
-	       isc_uint8_t *scope,
+	       uint8_t ecslen,
+	       uint8_t *scope,
 	       const dns_acl_t *acl,
 	       const dns_aclenv_t *env,
 	       int *match,
 	       const dns_aclelement_t **matchelt)
 {
-	isc_uint16_t bitlen;
+	uint16_t bitlen;
 	isc_prefix_t pfx;
 	isc_radix_node_t *node = NULL;
 	const isc_netaddr_t *addr = reqaddr;
@@ -221,7 +226,7 @@ dns_acl_match2(const isc_netaddr_t *reqaddr,
 
 	/* Always match with host addresses. */
 	bitlen = (addr->family == AF_INET6) ? 128 : 32;
-	NETADDR_TO_PREFIX_T(addr, pfx, bitlen, ISC_FALSE);
+	NETADDR_TO_PREFIX_T(addr, pfx, bitlen, false);
 
 	/* Assume no match. */
 	*match = 0;
@@ -231,12 +236,13 @@ dns_acl_match2(const isc_netaddr_t *reqaddr,
 
 	/* Found a match. */
 	if (result == ISC_R_SUCCESS && node != NULL) {
-		int off = ISC_RADIX_OFF(&pfx);
-		match_num = node->node_num[off];
-		if (*(isc_boolean_t *) node->data[off])
+		int fam = ISC_RADIX_FAMILY(&pfx);
+		match_num = node->node_num[fam];
+		if (*(bool *) node->data[fam]) {
 			*match = match_num;
-		else
+		} else {
 			*match = -match_num;
+		}
 	}
 
 	isc_refcount_destroy(&pfx.refcount);
@@ -257,21 +263,23 @@ dns_acl_match2(const isc_netaddr_t *reqaddr,
 			addr = &v4addr;
 		}
 
-		NETADDR_TO_PREFIX_T(addr, pfx, ecslen, ISC_TRUE);
+		NETADDR_TO_PREFIX_T(addr, pfx, ecslen, true);
 
 		result = isc_radix_search(acl->iptable->radix, &node, &pfx);
 		if (result == ISC_R_SUCCESS && node != NULL) {
-			int off = ISC_RADIX_OFF(&pfx);
+			int off = ISC_RADIX_FAMILY(&pfx);
 			if (match_num == -1 ||
 			    node->node_num[off] < match_num)
 			{
 				match_num = node->node_num[off];
-				if (scope != NULL)
+				if (scope != NULL) {
 					*scope = node->bit;
-				if (*(isc_boolean_t *) node->data[off])
+				}
+				if (*(bool *) node->data[off]) {
 					*match = match_num;
-				else
+				} else {
 					*match = -match_num;
+				}
 			}
 		}
 
@@ -313,7 +321,7 @@ dns_acl_match2(const isc_netaddr_t *reqaddr,
  * an unexpected positive match in the parent ACL.
  */
 isc_result_t
-dns_acl_merge(dns_acl_t *dest, dns_acl_t *source, isc_boolean_t pos)
+dns_acl_merge(dns_acl_t *dest, dns_acl_t *source, bool pos)
 {
 	isc_result_t result;
 	unsigned int newalloc, nelem, i;
@@ -391,7 +399,7 @@ dns_acl_merge(dns_acl_t *dest, dns_acl_t *source, isc_boolean_t pos)
 
 		/* reverse sense of positives if this is a negative acl */
 		if (!pos && !source->elements[i].negative) {
-			dest->elements[nelem + i].negative = ISC_TRUE;
+			dest->elements[nelem + i].negative = true;
 		} else {
 			dest->elements[nelem + i].negative =
 				source->elements[i].negative;
@@ -414,14 +422,14 @@ dns_acl_merge(dns_acl_t *dest, dns_acl_t *source, isc_boolean_t pos)
 
 /*
  * Like dns_acl_match, but matches against the single ACL element 'e'
- * rather than a complete ACL, and returns ISC_TRUE iff it matched.
+ * rather than a complete ACL, and returns true iff it matched.
  *
  * To determine whether the match was positive or negative, the
  * caller should examine e->negative.  Since the element 'e' may be
  * a reference to a named ACL or a nested ACL, a matching element
  * returned through 'matchelt' is not necessarily 'e' itself.
  */
-isc_boolean_t
+bool
 dns_aclelement_match(const isc_netaddr_t *reqaddr,
 		     const dns_name_t *reqsigner,
 		     const dns_aclelement_t *e,
@@ -432,12 +440,12 @@ dns_aclelement_match(const isc_netaddr_t *reqaddr,
 				      e, env, matchelt));
 }
 
-isc_boolean_t
+bool
 dns_aclelement_match2(const isc_netaddr_t *reqaddr,
 		      const dns_name_t *reqsigner,
 		      const isc_netaddr_t *ecs,
-		      isc_uint8_t ecslen,
-		      isc_uint8_t *scope,
+		      uint8_t ecslen,
+		      uint8_t *scope,
 		      const dns_aclelement_t *e,
 		      const dns_aclenv_t *env,
 		      const dns_aclelement_t **matchelt)
@@ -457,9 +465,9 @@ dns_aclelement_match2(const isc_netaddr_t *reqaddr,
 		    dns_name_equal(reqsigner, &e->keyname)) {
 			if (matchelt != NULL)
 				*matchelt = e;
-			return (ISC_TRUE);
+			return (true);
 		} else
-			return (ISC_FALSE);
+			return (false);
 
 	case dns_aclelementtype_nestedacl:
 		inner = e->nestedacl;
@@ -467,27 +475,27 @@ dns_aclelement_match2(const isc_netaddr_t *reqaddr,
 
 	case dns_aclelementtype_localhost:
 		if (env == NULL || env->localhost == NULL)
-			return (ISC_FALSE);
+			return (false);
 		inner = env->localhost;
 		break;
 
 	case dns_aclelementtype_localnets:
 		if (env == NULL || env->localnets == NULL)
-			return (ISC_FALSE);
+			return (false);
 		inner = env->localnets;
 		break;
 
 #ifdef HAVE_GEOIP
 	case dns_aclelementtype_geoip:
 		if (env == NULL || env->geoip == NULL)
-			return (ISC_FALSE);
+			return (false);
 		addr = (env->geoip_use_ecs && ecs != NULL) ? ecs : reqaddr;
 		return (dns_geoip_match(addr, scope, env->geoip,
 					&e->geoip_elem));
 #endif
 	default:
-		/* Should be impossible. */
 		INSIST(0);
+		ISC_UNREACHABLE();
 	}
 
 	result = dns_acl_match2(reqaddr, reqsigner, ecs, ecslen, scope,
@@ -503,7 +511,7 @@ dns_aclelement_match2(const isc_netaddr_t *reqaddr,
 	if (indirectmatch > 0) {
 		if (matchelt != NULL)
 			*matchelt = e;
-		return (ISC_TRUE);
+		return (true);
 	}
 
 	/*
@@ -513,7 +521,7 @@ dns_aclelement_match2(const isc_netaddr_t *reqaddr,
 	if (matchelt != NULL)
 		*matchelt = NULL;
 
-	return (ISC_FALSE);
+	return (false);
 }
 
 void
@@ -566,7 +574,7 @@ dns_acl_detach(dns_acl_t **aclp) {
 
 static isc_once_t	insecure_prefix_once = ISC_ONCE_INIT;
 static isc_mutex_t	insecure_prefix_lock;
-static isc_boolean_t	insecure_prefix_found;
+static bool	insecure_prefix_found;
 
 static void
 initialize_action(void) {
@@ -582,10 +590,10 @@ is_insecure(isc_prefix_t *prefix, void **data) {
 	/*
 	 * If all nonexistent or negative then this node is secure.
 	 */
-	if ((data[0] == NULL || !* (isc_boolean_t *) data[0]) &&
-	    (data[1] == NULL || !* (isc_boolean_t *) data[1]) &&
-	    (data[2] == NULL || !* (isc_boolean_t *) data[2]) &&
-	    (data[3] == NULL || !* (isc_boolean_t *) data[3]))
+	if ((data[0] == NULL || !* (bool *) data[0]) &&
+	    (data[1] == NULL || !* (bool *) data[1]) &&
+	    (data[2] == NULL || !* (bool *) data[2]) &&
+	    (data[3] == NULL || !* (bool *) data[3]))
 		return;
 
 	/*
@@ -594,35 +602,35 @@ is_insecure(isc_prefix_t *prefix, void **data) {
 	 */
 	if (prefix->bitlen == 32 &&
 	    htonl(prefix->add.sin.s_addr) == INADDR_LOOPBACK &&
-	    (data[1] == NULL || !* (isc_boolean_t *) data[1]) &&
-	    (data[2] == NULL || !* (isc_boolean_t *) data[2]) &&
-	    (data[3] == NULL || !* (isc_boolean_t *) data[3]))
+	    (data[1] == NULL || !* (bool *) data[1]) &&
+	    (data[2] == NULL || !* (bool *) data[2]) &&
+	    (data[3] == NULL || !* (bool *) data[3]))
 		return;
 
 	if (prefix->bitlen == 128 &&
 	    IN6_IS_ADDR_LOOPBACK(&prefix->add.sin6) &&
-	    (data[0] == NULL || !* (isc_boolean_t *) data[0]) &&
-	    (data[2] == NULL || !* (isc_boolean_t *) data[2]) &&
-	    (data[3] == NULL || !* (isc_boolean_t *) data[3]))
+	    (data[0] == NULL || !* (bool *) data[0]) &&
+	    (data[2] == NULL || !* (bool *) data[2]) &&
+	    (data[3] == NULL || !* (bool *) data[3]))
 		return;
 
 	/* Non-negated, non-loopback */
-	insecure_prefix_found = ISC_TRUE;	/* LOCKED */
+	insecure_prefix_found = true;	/* LOCKED */
 	return;
 }
 
 /*
- * Return ISC_TRUE iff the acl 'a' is considered insecure, that is,
+ * Return true iff the acl 'a' is considered insecure, that is,
  * if it contains IP addresses other than those of the local host.
  * This is intended for applications such as printing warning
  * messages for suspect ACLs; it is not intended for making access
  * control decisions.  We make no guarantee that an ACL for which
- * this function returns ISC_FALSE is safe.
+ * this function returns false is safe.
  */
-isc_boolean_t
+bool
 dns_acl_isinsecure(const dns_acl_t *a) {
 	unsigned int i;
-	isc_boolean_t insecure;
+	bool insecure;
 
 	RUNTIME_CHECK(isc_once_do(&insecure_prefix_once,
 				  initialize_action) == ISC_R_SUCCESS);
@@ -632,12 +640,12 @@ dns_acl_isinsecure(const dns_acl_t *a) {
 	 * non-loopback prefixes.
 	 */
 	LOCK(&insecure_prefix_lock);
-	insecure_prefix_found = ISC_FALSE;
+	insecure_prefix_found = false;
 	isc_radix_process(a->iptable->radix, is_insecure);
 	insecure = insecure_prefix_found;
 	UNLOCK(&insecure_prefix_lock);
 	if (insecure)
-		return (ISC_TRUE);
+		return (true);
 
 	/* Now check non-radix elements */
 	for (i = 0; i < a->length; i++) {
@@ -654,20 +662,23 @@ dns_acl_isinsecure(const dns_acl_t *a) {
 
 		case dns_aclelementtype_nestedacl:
 			if (dns_acl_isinsecure(e->nestedacl))
-				return (ISC_TRUE);
+				return (true);
 			continue;
 
+#ifdef HAVE_GEOIP
+		case dns_aclelementtype_geoip:
+#endif
 		case dns_aclelementtype_localnets:
-			return (ISC_TRUE);
+			return (true);
 
 		default:
 			INSIST(0);
-			return (ISC_TRUE);
+			ISC_UNREACHABLE();
 		}
 	}
 
 	/* No insecure elements were found. */
-	return (ISC_FALSE);
+	return (false);
 }
 
 /*
@@ -685,10 +696,10 @@ dns_aclenv_init(isc_mem_t *mctx, dns_aclenv_t *env) {
 	result = dns_acl_create(mctx, 0, &env->localnets);
 	if (result != ISC_R_SUCCESS)
 		goto cleanup_localhost;
-	env->match_mapped = ISC_FALSE;
+	env->match_mapped = false;
 #ifdef HAVE_GEOIP
 	env->geoip = NULL;
-	env->geoip_use_ecs = ISC_FALSE;
+	env->geoip_use_ecs = false;
 #endif
 	return (ISC_R_SUCCESS);
 
